[][src]Enum matrix_sdk_crypto::MegolmError

pub enum MegolmError {
    EventError(EventError),
    JsonError(SerdeError),
    MissingSession,
    OlmGroupSession(OlmGroupSessionError),
    Store(CryptoStoreError),
}

Error representing a failure during a group encryption operation.

Variants

EventError(EventError)

The event that should have been decrypted is malformed.

JsonError(SerdeError)

The received decrypted event couldn't be deserialized.

MissingSession

Decryption failed because the session needed to decrypt the event is missing.

OlmGroupSession(OlmGroupSessionError)

The underlying group session operation returned an error.

The storage layer returned an error.