[][src]Enum matrix_sdk_crypto::OlmError

pub enum OlmError {
    EventError(EventError),
    JsonError(SerdeError),
    OlmSession(OlmSessionError),
    OlmGroupSession(OlmGroupSessionError),
    Store(CryptoStoreError),
    SessionWedged(UserId, String),
    ReplayedMessage(UserId, String),
    MissingSession,
}

Error representing a failure during a device to device cryptographic operation.

Variants

EventError(EventError)

The event that should have been decrypted is malformed.

JsonError(SerdeError)

The received decrypted event couldn't be deserialized.

OlmSession(OlmSessionError)

The underlying Olm session operation returned an error.

OlmGroupSession(OlmGroupSessionError)

The underlying group session operation returned an error.

The storage layer returned an error.

SessionWedged(UserId, String)

The session with a device has become corrupted.

ReplayedMessage(UserId, String)

An Olm message got replayed while the Olm ratchet has already moved forward.

MissingSession

Encryption failed because the device does not have a valid Olm session with us.