[][src]Struct matrix_sdk_crypto::olm::ExportedRoomKey

pub struct ExportedRoomKey {
    pub algorithm: EventEncryptionAlgorithm,
    pub room_id: RoomId,
    pub sender_key: String,
    pub session_id: String,
    pub session_key: ExportedGroupSessionKey,
    pub sender_claimed_keys: BTreeMap<DeviceKeyAlgorithm, String>,
    pub forwarding_curve25519_key_chain: Vec<String>,
}

An exported version of a InboundGroupSession

This can be used to share the InboundGroupSession in an exported file.

Fields

algorithm: EventEncryptionAlgorithm

The encryption algorithm that the session uses.

room_id: RoomId

The room where the session is used.

sender_key: String

The Curve25519 key of the device which initiated the session originally.

session_id: String

The ID of the session that the key is for.

session_key: ExportedGroupSessionKey

The key for the session.

sender_claimed_keys: BTreeMap<DeviceKeyAlgorithm, String>

The Ed25519 key of the device which initiated the session originally.

forwarding_curve25519_key_chain: Vec<String>

Chain of Curve25519 keys through which this session was forwarded, via m.forwarded_room_key events.