[][src]Enum matrix_sdk_crypto::store::CryptoStoreError

pub enum CryptoStoreError {
    AccountUnset,
    DatabaseError(SqlxError),
    Io(IoError),
    OlmAccount(OlmAccountError),
    OlmSession(OlmSessionError),
    OlmGroupSession(OlmGroupSessionError),
    SessionUnpickling(SessionUnpicklingError),
    UnpicklingError,
    IdentifierValidation(IdentifierValidationError),
    Serialization(SerdeError),
}

The crypto store's error type.

Variants

AccountUnset

The account that owns the sessions, group sessions, and devices wasn't found.

DatabaseError(SqlxError)

SQL error occurred.

An IO error occurred.

OlmAccount(OlmAccountError)

The underlying Olm Account operation returned an error.

OlmSession(OlmSessionError)

The underlying Olm session operation returned an error.

OlmGroupSession(OlmGroupSessionError)

The underlying Olm group session operation returned an error.

SessionUnpickling(SessionUnpicklingError)

A session time-stamp couldn't be loaded.

UnpicklingError

Failed to decrypt an pickled object.

IdentifierValidation(IdentifierValidationError)

A Matirx identifier failed to be validated.

Serialization(SerdeError)

The store failed to (de)serialize a data type.