[][src]Struct matrix_sdk_crypto::Device

pub struct Device { /* fields omitted */ }

A device represents a E2EE capable client of an user.

Implementations

impl Device[src]

pub async fn start_verification(&self) -> StoreResult<(Sas, ToDeviceRequest)>[src]

Start a interactive verification with this Device

Returns a Sas object and to-device request that needs to be sent out.

pub fn trust_state(&self) -> bool[src]

Get the trust state of the device.

pub async fn set_local_trust(&self, trust_state: LocalTrust) -> StoreResult<()>[src]

Set the local trust state of the device to the given state.

This won't affect any cross signing trust state, this only sets a flag marking to have the given trust state.

Arguments

  • trust_state - The new trust state that should be set for the device.

pub async fn encrypt_session(
    &self,
    session: InboundGroupSession
) -> Result<(Session, EncryptedEventContent), OlmError>
[src]

Encrypt the given inbound group session as a forwarded room key for this device.

Methods from Deref<Target = ReadOnlyDevice>

pub fn user_id(&self) -> &UserId[src]

The user id of the device owner.

pub fn device_id(&self) -> &DeviceId[src]

The unique ID of the device.

pub fn display_name(&self) -> &Option<String>[src]

Get the human readable name of the device.

pub fn get_key(&self, algorithm: DeviceKeyAlgorithm) -> Option<&String>[src]

Get the key of the given key algorithm belonging to this device.

pub fn keys(&self) -> &BTreeMap<DeviceKeyId, String>[src]

Get a map containing all the device keys.

pub fn signatures(&self) -> &BTreeMap<UserId, BTreeMap<DeviceKeyId, String>>[src]

Get a map containing all the device signatures.

pub fn local_trust_state(&self) -> LocalTrust[src]

Get the trust state of the device.

pub fn is_trusted(&self) -> bool[src]

Is the device locally marked as trusted.

pub fn is_blacklisted(&self) -> bool[src]

Is the device locally marked as blacklisted.

Blacklisted devices won't receive any group sessions.

pub fn algorithms(&self) -> &[EventEncryptionAlgorithm][src]

Get the list of algorithms this device supports.

pub fn deleted(&self) -> bool[src]

Is the device deleted.